﻿using System;

using DevExpress.Utils.Menu;
using DevExpress.XtraGrid.Columns;
using DevExpress.XtraGrid.Menu;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 그리드 뷰 컬럼 버튼 메뉴
    /// </summary>
    public class GridViewColumnButtonMenu : GridViewMenu
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - GridViewColumnButtonMenu(gridView)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="gridView">그리드 뷰</param>
        public GridViewColumnButtonMenu(GridView gridView) : base(gridView)
        {
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 항목 생성하기 - CreateItems()

        /// <summary>
        /// 항목 생성하기
        /// </summary>
        protected override void CreateItems()
        {
            Items.Clear();

            DXSubMenuItem sumMenuItem = new DXSubMenuItem("Columns");

            Items.Add(sumMenuItem);

            Items.Add
            (
                CreateMenuItem
                (
                    "Runtime Column Customization",
                    GridMenuImages.Column.Images[3],
                    "Customization",
                    true
                )
            );

            foreach(GridColumn column in View.Columns)
            {
                if(column.OptionsColumn.ShowInCustomizationForm && column.GroupIndex < 0)
                {
                    sumMenuItem.Items.Add
                    (
                        CreateMenuCheckItem
                        (
                            column.GetCaption(),
                            column.Visible,
                            null,
                            column,
                            true
                        )
                    );
                }
            }
        }

        #endregion
        #region 메뉴 항목 체크 변경시 처리하기 - OnMenuItemCheckedChanged(sender, e)

        /// <summary>
        /// 메뉴 항목 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        protected override void OnMenuItemCheckedChanged(object sender, EventArgs e)
        {
            DXMenuCheckItem menuCheckItem = sender as DXMenuCheckItem;

            if(menuCheckItem.Tag is GridColumn)
            {
                GridColumn column = menuCheckItem.Tag as GridColumn;

                column.Visible = menuCheckItem.Checked;
            }
        }

        #endregion
        #region 메뉴 항목 클릭시 처리하기 - OnMenuItemClick(sender, e)

        /// <summary>
        /// 메뉴 항목 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        protected override void OnMenuItemClick(object sender, EventArgs e)
        {
            DXMenuItem menuItem = sender as DXMenuItem;

            if(menuItem.Tag == null)
            {
                return;
            }

            if(menuItem.Tag.ToString() == "Customization")
            {
                View.ShowCustomization();
            }
        }

        #endregion
    }
}