﻿using System.Data.OleDb;
using System.Drawing;
using System.Windows.Forms;

using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid.Menu;
using DevExpress.XtraGrid.Views.Grid;
using DevExpress.XtraGrid.Views.Grid.ViewInfo;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 연결
        /// </summary>
        private OleDbConnection connection;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.connection = new OleDbConnection("Provider=Microsoft.Jet.OLEDB.4.0;Data Source=nwind.mdb");

            this.gridView.InitializeView
            (
                true,                           // Multi Select
                GridMultiSelectMode.CellSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,   // Draw Focus Rect Style
                true,                           // Show Indicator
                true,                           // Show Column Headers
                true,                           // Allow Column Moving
                true,                           // Allow Column Resizing
                true,                           // Allow Filter
                true,                           // Allow Sort
                false,                          // Allow Cell Merge
                EditorShowMode.Default,         // Editor Show Mode
                false                           // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridControl.DataSource = Product.GetProductList(this.connection);

            this.gridView.BestFitColumns();

            this.gridView.MouseDown += gridView_MouseDown;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 그리드 뷰 마우스 DOWN 처리하기 - gridView_MouseDown(sender, e)

        /// <summary>
        /// 그리드 뷰 마우스 DOWN 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_MouseDown(object sender, MouseEventArgs e)
        {
            GridView gridView = sender as GridView;

            if(e.Button == MouseButtons.Right)
            {
                ShowMenu(gridView.CalcHitInfo(new Point(e.X, e.Y)));
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Function

        #region 메뉴 표시하기 - ShowMenu(gridHitInfo)

        /// <summary>
        /// 메뉴 표시하기
        /// </summary>
        /// <param name="gridHitInfo">그리드 히트 정보</param>
        private void ShowMenu(GridHitInfo gridHitInfo)
        {
            GridViewMenu gridViewMenu = null;

            if(gridHitInfo.HitTest == GridHitTest.ColumnButton)
            {
                gridViewMenu = new GridViewColumnButtonMenu(gridHitInfo.View);

                gridViewMenu.Init(gridHitInfo);
        
                gridViewMenu.Show(gridHitInfo.HitPoint);
             }
        }

        #endregion
    }
}